@@ -209,7 +209,7 @@ func writeJson(obj interface{}, w http.ResponseWriter) {
 	if err != nil {
 		http.Error(w, err.Error(), http.StatusInternalServerError)
 	} else {
-		fmt.Fprint(w, string(bytes)+"\n")
+		fmt.Fprintf(w, "%s\n", string(bytes))
 	}
 }
 
