@@ -89,7 +89,7 @@ func GetConsoleData(cc *ClusterContext, consoleUser, consolePass string) (data.C
 
 	if err = json.Unmarshal([]byte(resp.Body), &payload); err != nil {
 		if strings.HasPrefix(resp.Body, "Error") {
-			log.Print(resp.Body)
+			log.Printf("%s", resp.Body)
 			return consoleData, fmt.Errorf("%s", resp.Body)
 		} else {
 			log.Printf("error unmarshalling Payload: %s", err)
@@ -118,7 +118,7 @@ func GetConsoleData(cc *ClusterContext, consoleUser, consolePass string) (data.C
 
 	if err = json.Unmarshal([]byte(resp.Body), &payload); err != nil {
 		if strings.HasPrefix(resp.Body, "Error") {
-			log.Print(resp.Body)
+			log.Printf("%s", resp.Body)
 			return consoleData, fmt.Errorf("%s", resp.Body)
 		} else {
 			log.Printf("error unmarshalling Payload: %s", err)
