@@ -30,9 +30,9 @@ func SystemdUnitAvailable(gatewayName string) bool {
 	stdout, _, err := systemctlCommand("list-unit-files", s)
 	if err != nil {
 		log.Printf("systemd user unit not found: %s - %s", s, err)
-		log.Print(stdout)
+		log.Printf("%s", stdout)
 	} else if strings.Contains(stdout, "0 unit") {
-		log.Print(stdout)
+		log.Printf("%s", stdout)
 		return false
 	}
 	return err == nil
